/***************************************************************
                                                             
                    CRAVE                  
                                                              
 This file is distributed under the GNU General Public        
 License, Version 2. See the file COPYING.txt for more    
 details                                                      
                                                              
****************************************************************/

#include "./crave.h"

int main(argc, argv)
int argc;
char *argv[];
{
  INFO info;
  int print;
  double t11;

  clock();

  /* Initialize the info structure and parse the user options */
  FPT_LOG_FILE = NULL;
  init(&info, argv, argc);
  print = info.print;

  /* Check for a log file and open it */
  if (info.log_file != NULL) FPT_LOG_FILE = open_file(info.log_file, "w");

  if (print) {
    printf_s("-----\n", NULL);
    printf_s("Begin\n", NULL);
    printf_s("-----\n", NULL);
  }

  /* Open the output file */
  open_out(&info);
  if (print > 1) print_info(&info, 1);

  /* Open the genotype data */
  my_fopen(info.geno_file, &info.gfpt);

  /* Get the phenotype data */
  if (print) {
    printf_s("-----------------------\n", NULL);
    printf_s("Load the phenotype data\n", NULL);
    printf_s("-----------------------\n", NULL);
  }
  getPheno2(&info);
  if (print > 1) print_info(&info, 2);

  /* Get the columns in the genotype file and check them */
  if (print) {
    printf_s("-----------------------------------------------\n", NULL);
    printf_s("Load and check the columns in the genotype file\n", NULL);
    printf_s("-----------------------------------------------\n", NULL);
  }
  getCols(&info);
  if (print > 1) print_info(&info, 3);
  update_info(&info);

  if (print > 1) print_info(&info, 4);

  /* Process the snps */
  if (print) {
    printf_s("-------------------------------\n", NULL);
    printf_s("Begin reading the genotype data\n", NULL);
    printf_s("-------------------------------\n", NULL);
  }
  read_geno(&info);

  /* Output genes in last chromosome */
  chrPermsOutput(&info);
  
  my_fclose(&info.gfpt);
  if (print) {
    printf_s("-------------------\n", NULL);
    printf_s("Free info structure\n", NULL);
    printf_s("-------------------\n", NULL);
  }
  free_info(&info);

  /* Total time */
  t11 = (double) clock()/CLOCKS_PER_SEC;
  if (print) {
    if (t11 < 60.0) {
      printf_d("\nTotal time is %.0f seconds\n", t11);
    } else if (t11 < 3600.0) {
      printf_d("\nTotal time is %.1f minutes\n", t11/60.0);
    } else {
      printf_d("\nTotal time is %.2f hours\n", t11/3600.0);
    }
  }

  if (FPT_LOG_FILE) fclose(FPT_LOG_FILE);

  return(0);
}
